# coding: utf-8

"""
    ThingsBoard REST API

     ThingsBoard Professional Edition IoT platform REST API documentation.  # noqa: E501

    OpenAPI spec version: 3.7.0PE
    Contact: info@thingsboard.io
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

#  Copyright 2024. ThingsBoard
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

import pprint
import re  # noqa: F401

import six

class SnmpMapping(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'oid': 'str',
        'key': 'str',
        'data_type': 'str'
    }

    attribute_map = {
        'oid': 'oid',
        'key': 'key',
        'data_type': 'dataType'
    }

    def __init__(self, oid=None, key=None, data_type=None):  # noqa: E501
        """SnmpMapping - a model defined in Swagger"""  # noqa: E501
        self._oid = None
        self._key = None
        self._data_type = None
        self.discriminator = None
        if oid is not None:
            self.oid = oid
        if key is not None:
            self.key = key
        if data_type is not None:
            self.data_type = data_type

    @property
    def oid(self):
        """Gets the oid of this SnmpMapping.  # noqa: E501


        :return: The oid of this SnmpMapping.  # noqa: E501
        :rtype: str
        """
        return self._oid

    @oid.setter
    def oid(self, oid):
        """Sets the oid of this SnmpMapping.


        :param oid: The oid of this SnmpMapping.  # noqa: E501
        :type: str
        """

        self._oid = oid

    @property
    def key(self):
        """Gets the key of this SnmpMapping.  # noqa: E501


        :return: The key of this SnmpMapping.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this SnmpMapping.


        :param key: The key of this SnmpMapping.  # noqa: E501
        :type: str
        """

        self._key = key

    @property
    def data_type(self):
        """Gets the data_type of this SnmpMapping.  # noqa: E501


        :return: The data_type of this SnmpMapping.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this SnmpMapping.


        :param data_type: The data_type of this SnmpMapping.  # noqa: E501
        :type: str
        """
        allowed_values = ["BOOLEAN", "LONG", "DOUBLE", "STRING", "JSON"]  # noqa: E501
        if data_type not in allowed_values:
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SnmpMapping, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SnmpMapping):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
